==> iobroker.fullcalendar-0.1.0.tgz: package/admin/words.js <==
var systemDictionary = {
    "Events":           {"en": "Events",        "de": "Ereignisse",             "ru": "События"},
    "Single event":     {"en": "Single event",  "de": "Einzelereignis",         "ru": "Одиночное"},
    "Double event":     {"en": "Double event",  "de": "An/Aus Ereignis",        "ru": "Несколько"},
    "Toggle event":     {"en": "Toggle event",  "de": "Umschaltereignis",       "ru": "Переключение"},
    "Description":      {"en": "Description",   "de": "Beschreibung",           "ru": "Описание"},
    "Event type":       {"en": "Event type",    "de": "Eventtyp",               "ru": "Тип события"},
    "single":           {"en": "single",        "de": "Einzel",                 "ru": "одиночное"},
    "double":           {"en": "double",        "de": "An/Aus",                 "ru": "несколько"},
    "toggle":           {"en": "toggle",        "de": "Umschalt",               "ru": "переключение"},
    "Duration":         {"en": "Duration",      "de": "Dauer",                  "ru": "Длительность"},
    "Object ID":        {"en": "Object ID",     "de": "Objekt ID",              "ru": "ID объекта"},
    "Start value":      {"en": "Start value",   "de": "Startwert",              "ru": "Значение"},
    "End value":        {"en": "End value",     "de": "Endwert",                "ru": "Конечное значение"},
    "Period":           {"en": "Period",        "de": "Period",                 "ru": "Повтор"},
    "once":             {"en": "once",          "de": "einmalig",               "ru": "единожды"},
    "daily":            {"en": "daily",         "de": "taglich",                "ru": "ежедневно"},
    "monthly":          {"en": "monthly",       "de": "monatlich",              "ru": "ежемесячно"},
    "Instruction":      {
        "en": "Drag and drop the events above to create a new one.<hr>Use ALT by dragging it to copy the events.",
        "de": "Schiebe die Ereignisse oben auf Kalendar um neue Ereignise zu erzeugen.<hr>Halt ALT beim schieben um die Ereignisse zu kopieren.",
        "ru": "Что бы создать новые события, перетащите события сверху на календарь.<hr>Что бы скопировать событие удерживайте ALT при перетаскивании."
    },
    "Active":           {"en": "Active",        "de": "Aktiviert",              "ru": "Активно"},
    "Time":             {"en": "Time",          "de": "Zeit",                   "ru": "Время"},
    "Delete":           {"en": "Delete",        "de": "Löschen",                "ru": "Удалить"},
    "Cancel":           {"en": "Cancel",        "de": "Abbrechen",              "ru": "Отмена"},
    "Save":             {"en": "Save",          "de": "Speichern",              "ru": "Сохранить"},
    "Configure event":  {"en": "Configure event", "de": "Ereignis einstellen",  "ru": "Настроить событие"},
    "No action":        {"en": "No action",     "de": "Keine Aktion",           "ru": "Нет действия"},
    "Set value":        {"en": "Set value",     "de": "Setze Wert",             "ru": "Установить значение"},
    "Set %s":           {"en": "Set %s",        "de": "Setze %s",               "ru": "Установить %s"},
    "Set %s to %s":     {"en": "Set %s to %s",  "de": "Setze %s zu %s",         "ru": "Установить %s в/на %s"},
    "Set to %s":        {"en": "Set to %s",     "de": "Setze zu %s",            "ru": "Установить в/на %s"}
};

==> iobroker.fullcalendar-0.1.1.tgz: package/admin/words.js <==
var systemDictionary = {
    "Events":           {"en": "Events",        "de": "Ereignisse",             "ru": "События"},
    "Single event":     {"en": "Single event",  "de": "Einzelereignis",         "ru": "Одиночное"},
    "Double event":     {"en": "Double event",  "de": "An/Aus Ereignis",        "ru": "Несколько"},
    "Toggle event":     {"en": "Toggle event",  "de": "Umschaltereignis",       "ru": "Переключение"},
    "Description":      {"en": "Description",   "de": "Beschreibung",           "ru": "Описание"},
    "Event type":       {"en": "Event type",    "de": "Eventtyp",               "ru": "Тип события"},
    "single":           {"en": "single",        "de": "Einzel",                 "ru": "одиночное"},
    "double":           {"en": "double",        "de": "An/Aus",                 "ru": "несколько"},
    "toggle":           {"en": "toggle",        "de": "Umschalt",               "ru": "переключение"},
    "Duration":         {"en": "Duration",      "de": "Dauer",                  "ru": "Длительность"},
    "Object ID":        {"en": "Object ID",     "de": "Objekt ID",              "ru": "ID объекта"},
    "Start value":      {"en": "Start value",   "de": "Startwert",              "ru": "Значение"},
    "End value":        {"en": "End value",     "de": "Endwert",                "ru": "Конечное значение"},
    "Period":           {"en": "Period",        "de": "Period",                 "ru": "Повтор"},
    "once":             {"en": "once",          "de": "einmalig",               "ru": "один раз"},
    "daily":            {"en": "daily",         "de": "taglich",                "ru": "ежедневно"},
    "monthly":          {"en": "monthly",       "de": "monatlich",              "ru": "ежемесячно"},
    "Instruction":      {
        "en": "Drag and drop the events above to create a new one.<hr>Use ALT by dragging it to copy the events.",
        "de": "Schiebe die Ereignisse oben auf Kalendar um neue Ereignise zu erzeugen.<hr>Halt ALT beim schieben um die Ereignisse zu kopieren.",
        "ru": "Что бы создать новые события, перетащите события сверху на календарь.<hr>Что бы скопировать событие удерживайте ALT при перетаскивании."
    },
    "Active":           {"en": "Active",        "de": "Aktiviert",              "ru": "Активно"},
    "Time":             {"en": "Time",          "de": "Zeit",                   "ru": "Время"},
    "Delete":           {"en": "Delete",        "de": "Löschen",                "ru": "Удалить"},
    "Cancel":           {"en": "Cancel",        "de": "Abbrechen",              "ru": "Отмена"},
    "Save":             {"en": "Save",          "de": "Speichern",              "ru": "Сохранить"},
    "Configure event":  {"en": "Configure event", "de": "Ereignis einstellen",  "ru": "Настроить событие"},
    "No action":        {"en": "No action",     "de": "Keine Aktion",           "ru": "Нет действия"},
    "Set value":        {"en": "Set value",     "de": "Setze Wert",             "ru": "Установить значение"},
    "Set %s":           {"en": "Set %s",        "de": "Setze %s",               "ru": "Установить %s"},
    "Set %s to %s":     {"en": "Set %s to %s",  "de": "Setze %s zu %s",         "ru": "Установить %s в/на %s"},
    "Set to %s":        {"en": "Set to %s",     "de": "Setze zu %s",            "ru": "Установить в/на %s"},

    "sunrise":          {'en': 'sunrise',       "de": 'Sonnenaufgang',          'ru': 'восход солнца'},
    "sunriseEnd":       {'en': 'sunrise end',   "de": 'Sonnenaufgang-Ende',     'ru': 'конец восхода'},
    "goldenHourEnd":    {'en': 'golden hour end',"de": '"Golden hour"-Ende',    'ru': 'конец золотого часа'},
    "solarNoon":        {'en': 'solar noon',    "de": 'Sonnenmittag',           'ru': 'солнечеый полдень'},
    "goldenHour":       {'en': 'golden hour',   "de": '"Golden hour"',          'ru': 'золотой час'},
    "sunsetStart":      {'en': 'sunset start',  "de": 'Sonnenuntergang-Anfang', 'ru': 'начало захода солнца'},
    "sunset":           {'en': 'sunset',        "de": 'Sonnenuntergang',        'ru': 'конец захода солнца'},
    "dusk":             {'en': 'dusk',          "de": 'Abenddämmerung',         'ru': 'сумерки'},
    "nauticalDusk":     {'en': 'nautical dusk', "de": 'Nautische Abenddämmerung', 'ru': 'навигационные сумерки'},
    "night":            {'en': 'night',         "de": 'Nacht',                  'ru': 'ночь'},
    "nightEnd":         {'en': 'night end',     "de": 'Nachtsende',             'ru': 'конец ночи'},
    "nauticalDawn":     {'en': 'nautical dawn', "de": 'Nautische Morgendämmerung','ru': 'навигационный рассвет'},
    "dawn":             {'en': 'dawn',          "de": 'Morgendämmerung',        'ru': 'рассвет'},
    "nadir":            {'en': 'nadir',         "de": 'Nadir',                  'ru': 'надир'},

    "time":             {"en": "time",          "de": "Zeit",                   "ru": "время"},
    "astro":            {"en": "astro",         "de": "astro",                  "ru": "астро"},
    "Offset":           {"en": "Offset in minutes", "de": "Offset in Minuten",   "ru": "Сдвиг в минутах"}
};
